| Title: | Scientometric Analysis Minciencias |
|---|---|
| Description: | The target of 'margaret' is help to extract data from Minciencias to analyze scientific production in Colombia. |
| Authors: | Sebastian Robledo [aut] (ORCID: <https://orcid.org/0000-0003-4357-4402>), Bryan Arias [aut, cre] (ORCID: <https://orcid.org/0000-0002-2215-6175>), Camilo Garcia [aut] (ORCID: <https://orcid.org/0000-0002-8498-6393>), Universidad Católica Luis Amigó [cph, fnd], Core of Science [cph, fnd] |
| Maintainer: | Bryan Arias <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-06-02 08:05:55 UTC |
| Source: | https://github.com/coreofscience/margaret |
This function get information from GrupLac.
getting_data(groups, researchers)getting_data(groups, researchers)
groups |
A dataframe with information about groups and links from GrupLAC |
researchers |
A dataframe with ID from google scholar form researchers |
Extracts data from Minciencias web pages about research groups and researchers.
## Not run: Load data in a dataframe of r groups <- read.csv(".../groups_information.csv", header=T, sep=",") margaret_data <- getting_data(groups) #or just margaret::getting_data(groups) ## End(Not run)## Not run: Load data in a dataframe of r groups <- read.csv(".../groups_information.csv", header=T, sep=",") margaret_data <- getting_data(groups) #or just margaret::getting_data(groups) ## End(Not run)
"Publindex homologación de revistas" 2003 to 2022
homologadas_publindexhomologadas_publindex
A dataframe with information about journal ranking from Publindex
https://scienti.minciencias.gov.co/publindex/#/revistasHomologadas/buscador
Publindex Nacional de revistas 2022
national_publindexnational_publindex
A dataframe with information about journal ranking from Publindex
https://scienti.minciencias.gov.co/publindex/#/revistasPublindex/historico
Scimago categories
scimago_categoriesscimago_categories
A dataframe with information about journal ranking from scimago
https://github.com/ikashnitsky/sjrdata https://www.scimagojr.com/